Crate asset_importer_rs_core

Crate asset_importer_rs_core 

Structs

AiImporterDesc
Description of an importer’s capabilities and metadata.
Spatial
A Spatial is a data structure that allows for fast lookup of positions within a radius. It sorts the positions by their distance from the centroid along the plane normal. It then uses a range search along that plane to find position candidates. Then those candidates are checked for actual 3D distance. This helps reduce the number of distance calculations needed.
SpatialEntry

Enums

AiImporterFlags
Flags that describe the capabilities and characteristics of an importer.
AiPostProcessSteps
ExportProperty

Constants

AI_CONFIG_CHECK_IDENTITY_MATRIX_EPSILON
Configuration key for checking identity matrix epsilon.
AI_CONFIG_CHECK_IDENTITY_MATRIX_EPSILON_DEFAULT
Default epsilon value for identity matrix checking.
AI_CONFIG_EXPORT_GLTF_UNLIMITED_SKINNING_BONES_PER_VERTEX
Configuration key for unlimited skinning bones per vertex in GLTF export.
AI_CONFIG_USE_GLTF_PBR_SPECULAR_GLOSSINESS
Configuration key for using GLTF PBR specular-glossiness workflow.
AI_METADATA_SOURCE_COPYRIGHT
Metadata key for the source asset copyright information.
AI_METADATA_SOURCE_FORMAT
Metadata key for the source asset format.
AI_METADATA_SOURCE_FORMAT_VERSION
Metadata key for the source asset format version.
AI_METADATA_SOURCE_GENERATOR
Metadata key for the source asset generator.
GLTF2_NODE_IN_TRS
Configuration key for GLTF2 node transformation representation.
GLTF2_TARGET_NORMAL_EXP
Configuration key for GLTF2 target normal export.
INITIAL_PLANE_NORMAL

Traits

AiExport
Trait for implementing scene export functionality.
AiExportExt
Extension trait providing convenient methods for scene export.
AiImporter
Trait for reading AiScene data from various sources.
AiImporterExt
Extension trait providing convenient methods for scene import.
AiImporterInfo
Trait for types that provide information about an importer.
AiPostProcess
Trait for implementing a post-processing step on an AiScene.
ReadSeek
Trait for types that can both read and seek.
SpatialLookup
Trait for implementing spatial lookup functionality to find positions within a given radius.

Functions

default_file_exporter
default_file_loader

Type Aliases

DataExporter
A type alias for a function that creates a writer for a path
DataLoader
A type alias for a function that loads data from a path
ExportProperties