Structs
- AiImporter
Desc - Description of an importer’s capabilities and metadata.
- Spatial
- A Spatial is a data structure that allows for fast lookup of positions within a radius. It sorts the positions by their distance from the centroid along the plane normal. It then uses a range search along that plane to find position candidates. Then those candidates are checked for actual 3D distance. This helps reduce the number of distance calculations needed.
- Spatial
Entry
Enums
- AiImporter
Flags - Flags that describe the capabilities and characteristics of an importer.
- AiPost
Process Steps - Export
Property
Constants
- AI_
CONFIG_ CHECK_ IDENTITY_ MATRIX_ EPSILON - Configuration key for checking identity matrix epsilon.
- AI_
CONFIG_ CHECK_ IDENTITY_ MATRIX_ EPSILON_ DEFAULT - Default epsilon value for identity matrix checking.
- AI_
CONFIG_ EXPORT_ GLTF_ UNLIMITED_ SKINNING_ BONES_ PER_ VERTEX - Configuration key for unlimited skinning bones per vertex in GLTF export.
- AI_
CONFIG_ USE_ GLTF_ PBR_ SPECULAR_ GLOSSINESS - Configuration key for using GLTF PBR specular-glossiness workflow.
- AI_
METADATA_ SOURCE_ COPYRIGHT - Metadata key for the source asset copyright information.
- AI_
METADATA_ SOURCE_ FORMAT - Metadata key for the source asset format.
- AI_
METADATA_ SOURCE_ FORMAT_ VERSION - Metadata key for the source asset format version.
- AI_
METADATA_ SOURCE_ GENERATOR - Metadata key for the source asset generator.
- GLTF2_
NODE_ IN_ TRS - Configuration key for GLTF2 node transformation representation.
- GLTF2_
TARGET_ NORMAL_ EXP - Configuration key for GLTF2 target normal export.
- INITIAL_
PLANE_ NORMAL
Traits
- AiExport
- Trait for implementing scene export functionality.
- AiExport
Ext - Extension trait providing convenient methods for scene export.
- AiImporter
- Trait for reading
AiScenedata from various sources. - AiImporter
Ext - Extension trait providing convenient methods for scene import.
- AiImporter
Info - Trait for types that provide information about an importer.
- AiPost
Process - Trait for implementing a post-processing step on an
AiScene. - Read
Seek - Trait for types that can both read and seek.
- Spatial
Lookup - Trait for implementing spatial lookup functionality to find positions within a given radius.
Functions
Type Aliases
- Data
Exporter - A type alias for a function that creates a writer for a path
- Data
Loader - A type alias for a function that loads data from a path
- Export
Properties